<?php

if ( !class_exists( 'eShopMagic_customizeController' ) ) {

class eShopMagic_customizeController extends eShopMagic_Controller {
	
	public function __construct( $pluginSettings ) {

		
		$this->config = $pluginSettings;

		$this->stylesheets = Array(
			//'customize_styles' => 'customize_styles.css'
		);

		$this->javascripts = Array(
			//'customize_js' => 'customize_script.js'
		);
		
		$this->default_options = Array( 
					'emails' => Array( 
						'admin_replace' => NULL,
						'admin_recipients' => NULL,
						'customer_copy_recipients' => NULL
					),
					'misc' => Array(
						'replace_at_symbol' => NULL,
						'currency_code' => NULL,
						'currency_name' => NULL,
						'addfadein' => NULL,
						'addfadeout' => NULL,
						'ajaxaddedmessage' => NULL,
						'ajaxerrormessage' => NULL,
						'use_cookie' => TRUE
					),
					'payment' => Array(
						'authnet_xrelay' => NULL
				       	),
					'shipping' => Array(
						'link_target' => NULL,
						'link_title' => NULL,
						'zones' => Array( )
					),
					'checkout' => Array(
						'mandatory' => Array(
							'shipping' => TRUE,
							'first_name' => TRUE,
							'last_name' => TRUE,
							'email' => TRUE,
							'phone' => TRUE,
							'company' => NULL,
							'address' => TRUE,
							'city' => TRUE,
							'zip' => TRUE,
							'country' => TRUE,
							'ref' => NULL,
							'comments' => NULL,
							'pay' => TRUE,
							'signup' => NULL, 
							),
						)
					);

		extract( $pluginSettings['constants'] );

		$title = ucfirst( $plugin_menu_display_name );
		$this->menus = Array(
			Array(
				'type' => 'sub',
				'settingspage' => TRUE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'main',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'shipping',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'emails',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'misc',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'payment',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'checkout',
				'iconUrl' => '',
				'position' => '100'
			)
		);
		
		parent::__construct( $pluginSettings );

		# Shipping
		add_filter( 'eshop_rename_ship_zone', Array( $this, 'custom_shipping_zones' ) );
		add_filter( 'eShopCheckoutLinksAttr', Array( $this, 'shipping_link_attributes' ) );

		# Emails
		add_filter( 'eshop_gateway_details_email', Array( $this, 'extra_admin_emails' ) );
		add_action( 'eshop_send_customer_email', Array( $this, 'copy_customer_email' ), 10, 4 );

		# Misc
		add_filter( 'gettext', Array( $this, 'filter_eshop_text' ), 10, 3 );
		add_filter( 'eshop_currency_codes', Array( $this, 'add_currency_code') );
		add_filter( 'eshop_ajax_cart', array( $this, 'addto_cart_ajax_message_speed' ) );
		add_filter( 'eshopCartSuccess', array( $this, 'added_ajax_message' ) );
		add_filter( 'eshopCartQtyError', array( $this, 'cart_ajax_error_message' ) );
		add_filter( 'eshop_use_cookie', Array( $this, 'use_cookie' ) );

		# Payment
		add_filter( 'eshop_authorizenet_xrelay', Array( $this, 'authnet_xrelay' ) );
		
		# Checkout
		add_filter( 'eshopCheckoutReqd', array( $this, 'mandatory_fields' ) );
		
	}

	public function main( ) {

	    return null;
	}
	
	public function shipping( ) {

		if ( isset( $_POST['shipping_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
			$_POST['shipping']['zones'] = array_filter( $_POST['shipping']['zones'] );
			$this->options['shipping'] = $_POST['shipping'];
			$this->saveOptions( $this->options );
		}

		$this->view = $this->loadOptions( 'shipping' );

	}
	
	public function emails( ) {

		if ( isset( $_POST['emails_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
			$this->options['emails'] = $_POST['emails'];
			$this->saveOptions( $this->options );
		}
		
		$this->view = $this->loadOptions( 'emails' );

	}
	
	public function misc( ) {

		if ( isset( $_POST['misc_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
			$this->options['misc'] = $_POST['misc'];
			$this->saveOptions( $this->options );
		}
		
		$this->view = $this->loadOptions( 'misc' );

	}
	
	public function payment( ) {

		if ( isset( $_POST['payment_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
                        $this->updateOption( $_POST );
			$this->saveOptions( $this->options );
		}

		$this->view = $this->loadOptions( 'payment' );

	}
	
	// Checkout subpage
	public function checkout() {

		if ( isset( $_POST['checkout_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
			$data_post = (Array)$_POST['checkout']['mandatory'];
			foreach ( $this->options['checkout']['mandatory'] as $field => &$value ) {
				$value = array_key_exists( $field, $data_post );
			}
			$this->options['checkout'] = $this->options['checkout'];
			$this->saveOptions( $this->options );
		}

		$this->view = $this->loadOptions( 'checkout' );

	}

	public function use_cookie( $value ) {
    
		return $this->options['misc']['use_cookie'];

	}
	
	public function authnet_xrelay( ) {
	
		if ( $this->options['payment']['authnet_xrelay'] ) return 'TRUE'; # Must return a string
		
	}

	public function filter_eshop_text( $translation, $text, $domain ) {

		if ( $domain != 'eshop' ) return $translation;

		$translations = &get_translations_for_domain( 'eshop' );

		if ( isset( $this->options['misc'] ) && is_array( $this->options['misc'] ) ) extract( $this->options['misc'] );
		
		if ( isset( $replace_at_symbol ) ) {

			# This works on a product page
			if ( $text == '@ %1$s%2$s' ) {
				return $translations->translate( $replace_at_symbol . ' %1$s%2$s' );
			}

			# This is the example string in eShop wiki - not sure if it's redundant or not, so leaving it in for now
			if ( $text == '%1$s @ %2$s%3$s' ) {
				return $translations->translate( '%1$s ' . $replace_at_symbol . ' %2$s%3$s' );
			}

		}

		return $translation;

	}

	public function extra_admin_emails( $addresses ) {
		
		if ( empty( $this->options['emails']['admin_recipients'] ) ) return $addresses;

		if ( $this->options['emails']['admin_replace'] ) {
			return explode( ',', $this->options['emails']['admin_recipients'] );
		} else {
			return array_merge( $addresses, explode( ',', $this->options['emails']['admin_recipients'] ) );
		}

	}	

	public function copy_customer_email( $subject, $body, $headers, $array ) {
	
		if ( empty( $this->options['emails']['customer_copy_recipients'] ) ) return;
		
		$recipients = $this->options['emails']['customer_copy_recipients'];

		wp_mail( $recipients, $subject, $body, $headers );

	}

	public function custom_shipping_zones( $zones ) {

		return $this->options['shipping']['zones'];

	}
	
	public function shipping_link_attributes( ) {

		return "target='{$this->options['shipping']['link_target']}' title='{$this->options['shipping']['link_title']}'";

	}
	
	// Add A Currency
	// Ref: http://quirm.net/wiki/eshop/additional-plugins-and-code-snippets/add-a-currency/
	public function add_currency_code ( $currencycodes ) 
	{
		$key = $this->options['misc']['currency_code'];
		$name = $this->options['misc']['currency_name'];
		if($key && $name) {
			$currencycodes[$key] = __($name);
		}
		return $currencycodes;
	}
	
	// Remove Mandatory Fields
	// Ref: http://quirm.net/wiki/eshop/additional-plugins-and-code-snippets/remove-mandatory-fields-from-checkout/
	public function mandatory_fields ( $reqd ) {
	
		$mandatory = Array( );
		foreach ( $this->options['checkout']['mandatory'] as $field => $required ) {
			if ( $required ) $mandatory[] = $field;
		}
		//$mandatory[] = 'company';
		//print_r( $mandatory );
		return $mandatory;
	}
	
	// Customise Ajax Message
	// Ref: http://quirm.net/wiki/eshop/additional-plugins-and-code-snippets/customise-ajax-message/
	public function addto_cart_ajax_message_speed ( $eshopajaxcart ) 
	{
		// Note: values are in milliseconds 
		if ( $this->options['misc']['addfadein'] ) {
			$eshopajaxcart['addfadein'] = $this->options['misc']['addfadein'];
		}
		if ( $this->options['misc']['addfadeout'] ) {
			$eshopajaxcart['addfadeout'] = $this->options['misc']['addfadeout'];
		}
		return $eshopajaxcart;
	}
	
	public function added_ajax_message ( $message ) 
	{
		if ( $this->options['misc']['ajaxaddedmessage'] ) {
		      $message = __('<p>'.$this->options['misc']['ajaxaddedmessage'].'</p>');  
		}
		return $message;
	}
	
	public function cart_ajax_error_message ( $message )
	{
		if ( $this->options['misc']['ajaxerrormessage'] ) {
		      $message = '<p><strong class="eshoperror error">'.__($this->options['misc']['ajaxerrormessage'].'</strong></p>');  
		}
		return $message;
	}

}//end class
}//end if
