<?php

if ( !class_exists( 'eShopMagic_troubleshooterController' ) ) {

class eShopMagic_troubleshooterController extends eShopMagic_Controller {
	
	const ESHOPMAGIC_PAGE_FOUND = 1;
	const ESHOPMAGIC_SHORTCODE_MISSING = 2;
	const ESHOPMAGIC_PAGE_MISSING = 3;
	const ESHOPMAGIC_IS_HOME_PAGE = 4;
	const ESHOPMAGIC_PLUGIN_OK = 5;
	const ESHOPMAGIC_PLUGIN_WARNING = 6;

	public function __construct( $pluginSettings ) {

		$this->config = $pluginSettings;

		$this->stylesheets = Array(
			'troubleshooter_styles' => 'troubleshooter_styles.css'
		);

		$this->javascripts = Array(
			//'troubleshooter_js' => 'troubleshooter_script.js'
		);
		
		extract( $pluginSettings['constants'] );

		$title = ucfirst( $plugin_menu_display_name );
		$this->menus = Array(
			Array(
				'type' => 'sub',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Troubleshooter',
				'capability' => 'administrator',
				'menuSlug' => 'main',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Troubleshooter',
				'capability' => 'administrator',
				'menuSlug' => 'logs',
				'iconUrl' => '',
				'position' => '100'
			)
		);

		parent::__construct( $pluginSettings );

		# Logs
		add_action( 'wp', Array( $this, 'intercept' ) );
		add_filter( 'the_content', Array( $this, 'to_gateway' ), 20 );
	}

	public function main( ) {

		$this->view['checks'] = $this->config_checks( );

	}

	private function config_checks( ) {

		global $eshopoptions;

		if ( is_array( $eshopoptions ) ) extract( $eshopoptions );

		$checks['page']['shopping cart'] = $this->page_check( $cart, '[eshop_show_cart]' );
		$checks['page']['checkout'] = $this->page_check( $checkout, '[eshop_show_checkout]' );
		$checks['page']['order cancel'] = $this->page_check( $cart_cancel, '[eshop_show_cancel]' );
		$checks['page']['order success'] = $this->page_check( $cart_success, '[eshop_show_success]' );
		$checks['page']['shipping'] = $this->page_check( $cart_shipping, '[eshop_show_shipping]' );
		$checks['page']['downloads'] = $this->page_check( $show_downloads, '[eshop_show_downloads]' );
		$checks['page']['help'] = $this->page_check( $xtra_help );
		$checks['page']['privacy policy'] = $this->page_check( $xtra_privacy );
		$checks['page']['tax rates'] = $this->page_check( $details['tax'] );
		
		$checks['plugin'] = $this->conflicting_plugins( );

		return $checks;

	}

	private function conflicting_plugins( ) {

		$conflicting = Array(
			'sociable',
			'maintenance-mode',
			'jadecoder-sticky-permalinks',
			'simple-google-connect',
			'theme-my-login',
			'wp-html-compression',
			'wp-member',
			'yet-another-related-posts',
			'wp-super-cache',
			'w3-total-cache',
			'bad-behaviour',
			'automatic-facebook-converter',
			'facebook-like-thumbnail',
			'wpmu-membership'
		);

		$active = get_option( 'active_plugins' );

		if ( is_array( $active ) ) {
			foreach( $active as &$a ) {
				$a = dirname( $a );
			}
		}
		
		if ( is_array( $conflicting ) ) {
			foreach( $conflicting as $c ) {
				$nice_name = str_replace( Array( '-', '_' ), ' ', $c );
				$nice_name = ucwords( $nice_name );

				if ( in_array( $c, $active ) ) {
					$checks[$nice_name] = self::ESHOPMAGIC_PLUGIN_WARNING;
				} else {
					$checks[$nice_name] = self::ESHOPMAGIC_PLUGIN_OK;
				}
			}
		}

		return $checks;
	}

	private function page_check( $post_id, $shortcode = '' ) {
		
		$page = get_post( $post_id, ARRAY_A );

		if ( !$page ) return self::ESHOPMAGIC_PAGE_MISSING;

		extract( $page );

		$front_page = get_option( 'page_on_front' );

		if ( $post_id == $front_page ) return self::ESHOPMAGIC_IS_HOME_PAGE;

		if ( $post_type != 'page' || $post_status != 'publish' ) return self::ESHOPMAGIC_PAGE_MISSING;

		if ( empty( $shortcode ) || preg_match( $shortcode, $post_content ) ) {
			return self::ESHOPMAGIC_PAGE_FOUND;
		} else {
			return self::ESHOPMAGIC_SHORTCODE_MISSING;
		}

	}

	public function logs( ) {

		$results = $this->model->simpleSelect( Array( 'limit' => 1, 'orderby' => Array( 'id' ) ) ); 

		$text = '';
		if ( is_array( $results ) ) {
			foreach( $results as $r ) {
				extract( $r );
				$sent = unserialize( $sent );
				$received = unserialize( $received );
				$eshopoptions = unserialize( $eshopoptions );

				$text .= "\r\n\r\n-- Eshop Settings --\r\n\r\n";
				$text .= print_r( $eshopoptions, TRUE );
				$text .= "\r\n\r\n-- Sent To Gateway --\r\n\r\n";
				$text .= print_r( $sent, TRUE );
				$text .= "\r\n\r\n-- Recieved From Gateway --\r\n\r\n";
				$text .= print_r( $received, TRUE );
				$text .= "\r\n\r\n-----\r\n\r\n";

			}
		}		
		
		$this->view['text'] = $text;

	}
	
	public function to_gateway( $content ) {

		global $eshopoptions;
		
		if ( is_page( $eshopoptions['checkout'] ) && isset( $_GET['eshopaction'] ) && $_GET['eshopaction'] == 'redirect' ) {

			$matches = preg_split( '/\/\>/', $content );
			foreach( $matches as $m ) {
				if ( preg_match( '/hidden/', $m ) ) {
					$s = preg_split( '/"/', $m );
					$toGateway[$s[3]] = $s[5];
				}
				if ( preg_match( '/form method/', $m ) ) {
					$s = preg_split( '/"/', $m );
					$toGateway['form_action'] = $s[7];
				}
			}
			$data = Array(
				'CheckId' => $toGateway['eshopident_1'],
				'Custom' => $toGateway['custom'],
				'Sent' => serialize( $toGateway ),
				'EshopOptions' => serialize( $eshopoptions )
			);

			$this->model->insert( $data );

		}	
		return $content;

	}

	public function intercept( ) {

		global $eshopoptions;

		$log_from_gateway = FALSE;

		if ( isset( $eshopoptions['cart_success'] ) && is_page( $eshopoptions['cart_success'] ) ) $log_from_gateway = TRUE;
		if ( isset( $eshopoptions['cart_fail'] ) && is_page( $eshopoptions['cart_fail'] ) ) $log_from_gateway = TRUE;

		if ( $log_from_gateway ) {

			if ( isset( $_POST['transaction_subject'] ) ) {
	
				$data = Array(
					'Received' => serialize( $_POST )
				);

				$where = Array(
					'Custom' => $_POST['transaction_subject']
				);

				$this->model->update( $data, $where );
			} else {
				error_log( 'Eshop Magic - Received from payment processor:');
				error_log( print_r( $_POST, 1 ) );
			}
		}

	}	


}

}
