<?php

if ( !class_exists( 'eShopMagic_Controller' ) ) {

class eShopMagic_Controller {

	private $pluginData = Array( );
	public $wp_option_name;
	public $uname;
	public $options = Array( );
	public $model;
	protected $default_options = Array( );
	private $controller;
	private $method;
	private $plugin;
	public $view;


	protected function __construct( $pluginData ) {
		
		$this->pluginData = $pluginData;
	
		$plugin_name = $this->pluginData['constants']['plugin_name'];

		$this->name = substr( str_replace( $plugin_name, '', get_class( $this ) ), 1, -10 );

		if ( isset( $_GET['page'] ) ) {
			$page_slug = explode( '_', $_GET['page'] );
			if ( count( $page_slug ) == 3 ) list( $this->plugin, $this->controller, $this->method ) = explode( '_', $_GET['page'] );
		}

		$this->wp_option_name = "{$this->pluginData['constants']['plugin_name']}_{$this->name}_settings";
		$this->options = $this->loadOptions( );

		add_action( 'init', array( $this, 'initHook' ) );

	}

	public function initHook( ) {

		if ( $this->controller == $this->name ) {
			# Load model
			$model_file_path = "{$this->pluginData['constants']['plugin_folder']}/models/{$this->controller}.model.php";
			if ( file_exists( $model_file_path ) ) {
				require_once( $model_file_path );
				$class_name = "{$this->controller}Model";
				$this->model = new $class_name( );
			}
			# Load stylesheets
			$this->initCSS( );
			# Load javascript
			$this->initJS( );
		}

		# Global Stylesheet
		$general_stylesheet = "/css/plugin_styles.css";
		if ( file_exists( $this->pluginData['constants']['plugin_folder'] . $general_stylesheet ) ) {
			$key = "{$this->pluginData['constants']['plugin_name']}_styles";
			wp_register_style( $key, $this->pluginData['constants']['plugin_url'] . $general_stylesheet );
			wp_enqueue_style( $key );
		}
	}

	public function loadPage( ) {

		$this->{$this->method}( );

		if ( is_array( $this->view ) ) extract( $this->view );

		if ( is_array( $this->pluginData['constants'] ) ) extract( $this->pluginData['constants'] );

		require_once( "{$plugin_folder}/views/layout.php" );
	}

	private function initCSS( ) {

		if ( !empty( $this->stylesheets ) ) {
			extract( $this->pluginData['constants'] );
			foreach( $this->stylesheets as $key => $url ) {
				if ( !preg_match( '/http:\/\//', $url ) ) $url = "{$plugin_url}/css/$url";
				wp_register_style( "{$plugin_name}_{$key}", $url );
				wp_enqueue_style( "{$key}_{$plugin_name}" );
			}
		}
	}

	private function initJS( ) {
		
		if ( !empty( $this->javascripts ) ) {
			extract( $this->pluginData['constants'] );
			foreach( $this->javascripts as $key => $url ) {
				if ( !preg_match( '/http:\/\//', $url ) ) $url = "{$plugin_url}/js/$url";
				if ( !empty( $url ) ) wp_register_script( "{$plugin_name}_{$key}", $url );
				wp_enqueue_script( "{$plugin_name}_{$key}" );
			}
		}
	}

	public function getMenus( ) {
		return $this->menus;
	}

	public function getPageUrl( $page, $controller = NULL ) {
		if ( is_null( $controller ) ) $controller = $this->controller;
		return get_admin_url( ) . "?page_id={$this->plugin}_{$controller}_$page";
	}

	public function getUniqueName( $tag = '' ) {
		# Will only work in action context (method will be blank elsewhere)
		return "{$this->plugin}_{$this->controller}_{$this->method}{$tag}";
	}

	public function getNonceField( $field_name = 'nonce' ) {
		return wp_nonce_field( $this->getUniqueName( ), $field_name );
	}

	public function nonceValid( $nonce ) {
		return wp_verify_nonce( $nonce, $this->getUniqueName( ) );
	}

	public function loadOptions( $key = NULL ) {
		
		$options = get_option( $this->wp_option_name );
		if ( empty( $options ) ) {
			$options = $this->default_options;
		} else {
                        $options = $this->array_merger($this->default_options, $options);
		}
		if ( isset( $key ) ) {
			$options = ( isset( $options[$key] ) ) ? $options[$key] : Array( );
		}
		return $options;
	}

	public function saveOptions( $options ) {
		update_option( $this->wp_option_name, $options );
	}

	private function combine_arrays($pairs, $atts) {
		$atts = (array)$atts;
		$out = array();
		foreach($pairs as $name => $default) {
			if ( array_key_exists($name, $atts) )
				$out[$name] = $atts[$name];
			else
				$out[$name] = $default;
		}
		return $out;
	}
        
        public function array_merger ( &$arr1, $arr2 ) {
                if (!count($arr1) && count($arr2)) {
                        $arr1 = $arr2;
                }
                foreach ($arr1 as $key => &$val) {
                        if (!is_array($val) && isset($arr2[$key])) {
                                if (!is_array($arr2[$key])) {
                                        $val = $arr2[$key];
                                }
                        } else {
                                if(isset($arr2[$key]) && is_array($arr2[$key])) {
                                        $this->array_merger($val, $arr2[$key]);
                                }
                        }
                }
                return $arr1;
        }
        
        public function updateOption ( $post ) {
                $this->options = $this->array_merger($this->options, $post);
        }

}

}
