<?php

/**
 * Class eShopMagic_HTMLComponents 
 * @description Generate re-usable HTML structures.
 * @author __construct
 */

if ( !class_exists( 'eShopMagic_HTMLComponents' ) ) {
class eShopMagic_HTMLComponents {

	private $options = Array( );

	public function __construct( $options = Array( ) ) {
		$this->options = $options;
	}

	public function __call( $type, $args ) {
		if ( count( $args ) > 1 ) {
			$e = new eShopMagic_HTMLElement( $type, $args[0], $args[1] );
		} else {
			$e = new eShopMagic_HTMLElement( $type, $args[0], '' );
		}

		$name = $e->name;
		if ( isset( $this->options['namePrefix'] ) && !empty( $name ) ) {
			$name = $e->name;
			$e->name = "{$this->options['namePrefix']}[{$name}]";
		}
		return $e;
	}

	public function simpleSelect( $attrs, Array $values, $selected_value = '' ) {

		$select = $this->select( $attrs );

		foreach( $values as $k => $v ) {
			# === and (string) required so that '0' and '' values work correctly in same select list
			$selected = ( $selected_value === (string)$v ) ? ',selected:' : '';
			$select->appendChild( $this->option( "value:{$v}{$selected}", "{$k}" ) ); 
		}

		return $select;
	}

	public function readonlyField( $label_text, $field_text, $class = '' ) {
		
		$label_div = $this->div( 'class:readonly-field-label', $this->strong( '', "{$label_text}:" ) );
		$field_div = $this->div( 'class:readonly-field-text', $this->span( "class:{$class}", $field_text ) );


		return $this->div( "class:readonly-field-wrapper", Array( $label_div, $field_div ) );

	}

	public function formField( $label_text, $field_control ) {

		$id = $field_control->id;
		$div = $this->div( "id:{$id}-div,class:form-field-wrapper" );

		$field_label = $this->label( "id:{$id}-label,class:form-field-label" );
		$field_label->appendChild( $label_text );
		$field_label->for = $id;

		$classes = $field_control->class;
		$type = $field_control->getElementType( );
		$field_control->setAttrs( "class:$classes form-field-{$type}" );

		$div->appendChildren( $this->div( 'class:field-label-div', $field_label ), $this->div( 'class:field-control-div', $field_control ) );

		return $div;
	}

	public function noticeBox( Array $messages, $title, $error = TRUE ) {

		if ( empty( $messages ) ) return '';

		$class = ( $error ) ? 'errorBox' : 'noticeBox';
		$listing = ( count( $messages ) == 1 ) ? $messages[0] : $this->listing( $messages );
		if ( $title ) $content[] = $this->h4( '', $title );
		$content[] = $listing;
		$div = $this->div( "class:$class rounded", $content );

		return $div;
	}

	public function listing( Array $items, $attrs = '', $ordered = FALSE ) {
		
		$l = ( $ordered ) ? $this->ol( $attrs ) : $this->ul( $attrs );

		foreach( $items as $i ) {
			$l->appendChild( $this->li( '', $i ) );
		}

		return $l;
	}

	public function wpEditor( $name = '', $class = 'wpEditor', $content = '' ) {
		ob_start( );
		$settings = Array(
			'media_buttons' => FALSE, # Won't work unless logged in anyway.
			'textarea_name' => "{$this->options['namePrefix']}[$name]",
			'textarea_rows' => '5',
			'editor_class' => $class,
			'tinymce' => array(
			    'theme_advanced_buttons1' => 'bold, italic, underline, strikethrough, bullist, numlist',
			    'theme_advanced_buttons2' => ''
			    ),
			'quicktags' => FALSE
		);
		wp_editor( $content, $class, $settings );
		$wpeditor = ob_get_clean( );

		return $this->div( 'class:wpEditor', $wpeditor );
	}

} // End class cpkHTMLComponents
} // End if

